@@ -1,5 +1,4 @@
 import dataclasses
-import sys
 
 from datetime import date, datetime, timedelta
 from typing import Sequence, Union
@@ -11,10 +10,7 @@ except ImportError:
 
     from typing_extensions import Literal, TypeVar  # type: ignore
 
-if sys.version_info >= (3, 9):
-    from collections import OrderedDict as OrderedDictType
-else:
-    from typing import OrderedDict as OrderedDictType
+from collections import OrderedDict as OrderedDictType
 
 
 class CreditCard:
@@ -37,7 +33,7 @@ BasicNumber = Union[float, int]
 CardType = TypeVar("CardType", "CreditCard", str)
 DateParseType = Union[date, datetime, timedelta, str, int]
 HueType = Union[str, float, int, Sequence[int]]
-SexLiteral = Literal["M", "F"]
+SexLiteral = Literal["M", "F", "X"]
 SeedType = Union[int, float, str, bytes, bytearray, None]
 
 
